@@ -1,12 +1,13 @@
 import typing
 from concurrent.futures import Future
+from typing import Optional
 
 from hedwig.backends.base import HedwigPublisherBaseBackend
 from hedwig.backends.utils import get_publisher_backend
 from hedwig.models import Message
 
 
-def publish(message: Message, backend: HedwigPublisherBaseBackend = None) -> typing.Union[str, Future]:
+def publish(message: Message, backend: Optional[HedwigPublisherBaseBackend] = None) -> typing.Union[str, Future]:
     """
     Publishes a message on Hedwig topic
     :returns: for async publishers, returns a future that represents the publish api call, otherwise, returns
